@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2009, Live Networks, Inc.  All rights reserved
 // A test program that receives a RTP/RTCP multicast MP3 stream,
 // and outputs the resulting MP3 file stream to 'stdout'
 // main program
@@ -54,7 +54,7 @@ int main(int argc, char** argv) {
   // A real file name could have been used instead.
 
   // Create 'groupsocks' for RTP and RTCP:
-  char* sessionAddressStr
+  char const* sessionAddressStr
 #ifdef USE_SSM
     = "232.255.42.42";
 #else
