@@ -11,9 +11,9 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2009, Live Networks, Inc.  All rights reserved
 // A test program that reads a MPEG-4 Video Elementary Stream file,
 // and streams both using RTP, through a remote Darwin Streaming Server.
 // main program
@@ -137,7 +137,7 @@ void play() {
 	 << "\" as a byte-stream file source\n";
     exit(1);
   }
-  
+
   FramedSource* videoES = fileSource;
 
   // Create a framer for the Video Elementary Stream:
